#ifndef FEM_H
#define FEM_H

#if defined(WIN32)
#ifdef fem_EXPORTS
#define FEM_API __declspec(dllexport)
#else
#define FEM_API __declspec(dllimport)
#endif
#else
#define FEM_API
#endif

#ifdef _MSC_VER
#pragma warning(disable : 4251) // DLL/templates non exportes
//#define NOMINMAX // avoids the definition of "min/max" macro  in <minwindef.h> (which could shadow std::max)
#endif //_MSC_VER

#include "config.h"
#include <vector>
#include <string>
#include <iostream>

namespace fem
{
class Problem;
class Entity;
class ElementSet;
class Group;
class Medium;
class Dirichlet;
class Neumann;
class Solver;
class Partition;
class Part;
class DOF;
class DOFs;
class DOFMask;
class Post;
class Timer;
class Extractor;
} // namespace fem

namespace fem
{

template <typename T>
std::ostream &
operator<<(std::ostream &out, std::vector<T> const &v)
{
    out << "[ ";
    for (auto const &i : v)
        out << i << " ";
    out << "]";
    return out;
}

template <typename T1, typename T2>
std::ostream &
operator<<(std::ostream &out, std::pair<T1, T2> const &v)
{
    out << "(" << v.first << "," << v.second << ")";
    return out;
}

FEM_API int debug_level(int lvl=-1);

} // namespace fem

#endif // FEM_H