#include "femGroup.h"
#include "femGmsh.h"

namespace fem
{

Group::Group(int _dim, int _tag) : dim(_dim), tag(_tag)
{
    gmsh::model::getPhysicalName(dim, tag, name);
    // this-> entities filled later with 'link_to_entities'
}

Group::~Group()
{
    if(debug_level()>0)
        std::cout << "~Group()\n";
}

void Group::link_to_entities(std::map<std::pair<int,int>, Entity*> const &entities_by_dimtag)
{
    std::vector<int> tags;
    gmsh::model::getEntitiesForPhysicalGroup(dim, tag, tags);
    for(auto tag : tags)
        entities.push_back( entities_by_dimtag.at(std::make_pair(dim,tag)) );
}

FEM_API std::ostream &
operator<<(std::ostream &out, Group const &obj)
{
    out << "Group \"" << obj.name << "\" (" << obj.dim << "d, " << obj.tag
        << ") made of " << obj.entities.size() << " entities";
    return out;
}

} // namespace fem
